@@ -2,7 +2,7 @@ import subprocess
 import os
 
 
-class DriverDAKOTA:
+class DriverDakota:
 
     def __init__(self, Dakota_path, analysis_yaml_path=None, dakota_input_folder=None, dakota_output_folder=None):
 
